@@ -161,7 +161,7 @@ def compare_preprocessing(X0, y ,nbPC=2, nb_comb=2, auto_x=1, auto_y=1, nb=60, C
     
     INPUT
     X0 [n x k] <numpy.ndarray>
-        X0 data to test pretreatments on
+        X0 data to test pre-processing techniques on
         n samples
         k variables
     y [n x m] <numpy.ndarray>
@@ -171,17 +171,17 @@ def compare_preprocessing(X0, y ,nbPC=2, nb_comb=2, auto_x=1, auto_y=1, nb=60, C
         
     OPTIONAL INPUT    
     nbPC <int>
-        number of components in the PLS the mbPLS decomposition (default value=2)
+        number of principal components for PLS in the mbPLS decomposition (default value=2)
     nb_comb <int>
-        maximum number of pre-processing techniques applied on data in a combination (default value=2)      
+        maximum number of pre-processing techniques applied on same data (default value=2)      
     auto_x <int>
-        autoscale data after applying pretreatments if auto_x=1, if not data centered (default value=1)
+        autoscale data after applying pre-processing technique if auto_x=1, if not data centered (default value=1)
     auto_y <int>
         autoscale variables to predict if auto_y=1, if not centered (default value=1)
     nb <int>
         number of random picks for cross validation
     CVnb <int>
-        number of lines predicted in each cross validation
+        number of samples predicted in each cross validation
     only_sg <int>
         only test Savitzky-Golay if only_sg=1 (default value=0)
     svg_order <list>
@@ -195,19 +195,20 @@ def compare_preprocessing(X0, y ,nbPC=2, nb_comb=2, auto_x=1, auto_y=1, nb=60, C
         
     OUTPUT
     combination <list>
-        pretreatments tested
+        Pre-processing techniques tested
     datasets0 <list>
-        data X0 after each pretreatment   
+        data X0 after each pre-processing technique  
     datasets <list>
-        data X0 after each pretreatment and autoscaled or centered   
+        data X0 after each pre-processing technique and autoscaled or centered   
     R2_all <list>   
-        R2 values for each y variable predicted for each pretreatment (block)
+        R2 values for each y variable predicted for each pre-processing technique tested (block)
     R2adj_all <list>   
-        R2 adjusted values for each y variable predicted for each pretreatment (block)
+        R2 adjusted values for each y variable predicted for each pre-processing technique tested (block)
     RMSECV_all <list>   
-        Root mean square error by cross validation for each y variable predicted for each pretreatment (block)
+        Root mean square error by cross validation for each y variable predicted for each pre-processing technique tested (block)
     VIP_all <list>   
-        PLS variable importance in projection for each y variable predicted for each pretreatment (block)     
+        PLS variable importance in projection for each y variable predicted for each pre-processing technique tested (block) 
+    
     '''
     
     #%% Save dimensions of data
