@@ -11,34 +11,26 @@ import numpy as np
 import matplotlib.pyplot as plt
 from fct_loadmat import loadmat
 from colorspectra_y import colorspectra_y
-
 import NIR_preprocess as nir_pre
 
 plt.close('all')
 
 #%% Load data
-
 data = loadmat('corn.mat')
-
 m5 = data['m5spec']['data']
-mp5 = data['mp5spec']['data']
-mp6 = data['mp6spec']['data']
-
 y = data['propvals']['data']
 
 # Set y values
-y1 = y[:,0][np.newaxis].T # mositure
+y1 = y[:,0][np.newaxis].T # moisture
 y2 = y[:,2][np.newaxis].T # protein
 
 y = np.concatenate([y1,y2], axis=1)
 
 # Choose which spectromoter to use
 X0 = m5
-
 n, k = X0.shape
 
 #%% Show original spectra
-
 colorspectra_y(X0,y1,y_label='Absorbance', x_label='Wavelength (nm)', colorbar_label='moisture')
 plt.text(0.01,0.85,'A', fontsize=12)
 plt.xticks([0, 300,600],[1100, 1700, 2300],fontsize=14)
@@ -48,5 +40,4 @@ plt.text(0.01,0.85,'B', fontsize=12)
 plt.xticks([0, 300,600],[1100, 1700, 2300],fontsize=14)
 
 #%% Compare pre-processing
-
-combination, datasets, datasets0, R2_all, R2adj_all, RMSECV_all, VIP_all, Ef_all, Wt = nir_pre.compare_preprocessing(X0, y, nbPC=3, nb=60)
\ No newline at end of file
+combination, datasets, datasets0, R2_all, R2adj_all, RMSECV_all, VIP_all, Ef_all, Wt = nir_pre.compare_preprocessing(X0, y, nbPC=3)
\ No newline at end of file
